@@ -6,23 +6,27 @@ all.Oxtcrss<-function(){
      cat("--------------------------------------------------------\n")  
      cat("\n")
      note_for_close_window()
-     OxtcrSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","c (mg/L)"),value=c(0))                   
-     OxtcrSSpar<-edit(OxtcrSSpar)                                                                                                                    
+     OxtcrSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","c (mg/L)"),
+                            value=c(1,65,167,0,1,600,12,7.34))
+     OxtcrSSpar<-edit(OxtcrSSpar)
+     
 ##     OxtcrSSpar<-ycheck(OxtcrSSpar)   
-     cat("\n")                                                                                                                 
+     cat("\n")
+     cat("\n Input data are as follows:\n")
+     cat(" --------------------------\n")
+     show(OxtcrSSpar);cat("\n\n")   
      Oxtcr.ss(OxtcrSSpar[8,2],OxtcrSSpar[7,2],OxtcrSSpar[6,2],OxtcrSSpar[3,2],OxtcrSSpar[2,2],OxtcrSSpar[5,2],OxtcrSSpar[1,2],OxtcrSSpar[4,2])
      note_for_convergence_plots()
-     convergence_plots_sep()
+     ### convergence_plots_sep()
      cat("-----------------------------------------------------------\n")
      cat("    --Oxtriphylline CR output data information--           \n")
      note_for_Thecr_output()
      cat("-----------------------------------------------------------\n")   
-     show(samplesStats("*"))
+     ### show(samplesStats("*"))
      cat("\n") 
      C<-TheCRcpr(0.65,OxtcrSSpar[6,2],OxtcrSSpar[7,2])
-     sim<-matrix(C[1 ,1])
-     coutput<-data.frame(sim)
-     colnames(coutput)<-list("Css_pr (mg/L)")     
+     ### sim<-matrix(C[1 ,1])
+     coutput<-data.frame(conc=c("Css_obs","Css_pr"),value=c(OxtcrSSpar[8,2],C))
      show(coutput)
      cat("\n")   
      Oxtcr.more()          
