@@ -18,19 +18,11 @@ all.Valss<-function(){
      note_for_Valss_output(ValSSpar[6,2])
      ### show(samplesStats("*"))
      cat("\n") 
-     C<-Valcpr(ValSSpar[4,2],ValSSpar[5,2],ValSSpar[6,2])   ### at time = 'ts'
+     C1<-Valcpr(ValSSpar[4,2],ValSSpar[5,2],ValSSpar[6,2])    ### at time = 'ts'
+     C2<-Valcpr(ValSSpar[4,2],ValSSpar[5,2],ValSSpar[5,2])    ### at time = 'tau'; the line is correct.   -YJ
      ### sim<-matrix(C[1 ,1])
-     coutput<-data.frame(C)
-     colnames(coutput)<-list("Cmss_pr (mg/L)")
-     output1<-coutput
-     show(coutput)
-     C<-Valcpr(ValSSpar[4,2],ValSSpar[5,2],ValSSpar[5,2])    ### at time = 'tau'; the line is correct.   -YJ
-     ### sim<-matrix(C[1 ,1])
-     coutput<-data.frame(C)
-     colnames(coutput)<-list("Ctss_pr (mg/L)")
-     output2<-coutput
-     show(coutput)    
-     cat("\n")   
+     coutput<-data.frame(Parameters=c("Cmss_pr (mg/L)","Ctss_pr (mg/L)"),Values=c(C1,C2))
+     cat("\n\n");show(coutput);cat("\n")   
      ### Val.more(ValSSpar[4,2])   ### originally 'ValSSpar[4,2] = ka'  we will leave it as one of to be estimated parameters. -YJ
      Val.more()
 }
\ No newline at end of file
